@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2010, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2010, 2016, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -633,7 +633,6 @@ def stop_running_server(server, wait=10, drop=True):
 
     res = server.show_server_variable("datadir")
     datadir = os.path.normpath(res[0][1])
-
     # Kill all connections so shutdown will work correctly
     res = server.exec_query("SHOW PROCESSLIST")
     for row in res:
@@ -843,14 +842,20 @@ class Server(object):
                 # Add alias with and without suffix from self.aliases
                 for alias in self.aliases:
                     if alias.endswith(suffix):
-                        host, _ = alias.rsplit('.')
-                        no_suffix_server_aliases.add(host)
+                        try:
+                            host, _ = alias.rsplit('.', 1)
+                            no_suffix_host_aliases.add(host)
+                        except:
+                            pass  # Ok if parts don't split correctly
                     no_suffix_server_aliases.add(alias)
                 # Add alias with and without suffix from host_aliases
                 for alias in host_or_ip_aliases:
                     if alias.endswith(suffix):
-                        host, _ = alias.rsplit('.')
-                        no_suffix_host_aliases.add(host)
+                        try:
+                            host, _ = alias.rsplit('.', 1)
+                            no_suffix_host_aliases.add(host)
+                        except:
+                            pass  # Ok if parts don't split correctly
                     no_suffix_host_aliases.add(alias)
             # Check if there is any alias in common
             common_alias = no_suffix_host_aliases.intersection(
@@ -1425,9 +1430,6 @@ class Server(object):
             errors.append("    GTID is not enabled.")
         if not self.check_version_compat(5, 6, 9):
             errors.append("    Server version must be 5.6.9 or greater.")
-        res = self.exec_query("SHOW VARIABLES LIKE 'gtid_executed'")
-        if res == [] or not res[0][0] == "gtid_executed":
-            errors.append("    Missing gtid_executed system variable.")
         if errors:
             errors = "\n".join(errors)
             errors = "\n".join([_GTID_ERROR % (self.host, self.port), errors])
@@ -1983,8 +1985,8 @@ class Server(object):
         Returns bool - True - foreign keys are enabled
         """
         if self.fkeys is None or force:
-            res = self.show_server_variable("foreign_key_checks")
-            self.fkeys = (res is not None) and (res[0][1] == "ON")
+            res = self.exec_query("SELECT @@GLOBAL.foreign_key_checks")
+            self.fkeys = (res is not None) and (res[0][0] == "1")
         return self.fkeys
 
     def disable_foreign_key_checks(self, disable=True):
